@@ -14,6 +14,7 @@
 #' now use function \code{\link{girafe}} and \code{\link{girafe_options}}.
 #'
 #' @inheritParams girafe
+#' @param width widget width ratio (0 < width <= 1).
 #' @param tooltip_extra_css extra css (added to \code{position: absolute;pointer-events: none;})
 #' used to customize tooltip area.
 #' @param hover_css css to apply when mouse is hover and element with a data-id attribute.
@@ -52,7 +53,7 @@ ggiraph <- function(code, ggobj = NULL,
     warning("argument `dep_dir` has been deprecated.")
   }
 
-  x <- girafe(code = code, ggobj = ggobj, width = width, pointsize = pointsize,
+  x <- girafe(code = code, ggobj = ggobj, pointsize = pointsize,
          width_svg = width_svg, height_svg = height_svg, xml_reader_options = xml_reader_options, ...)
   x <- girafe_options(
     x = x,
@@ -65,7 +66,8 @@ ggiraph <- function(code, ggobj = NULL,
     opts_zoom(min = 1, max = zoom_max),
     opts_selection(type = selection_type, css = selected_css),
     opts_toolbar(position = "top", saveaspng = FALSE),
-    opts_hover(css = hover_css)
+    opts_hover(css = hover_css),
+    opts_sizing(rescale = TRUE, width = width)
     )
 
   # fix for package ceterisParibus unit tests
@@ -95,10 +97,10 @@ ggiraph <- function(code, ggobj = NULL,
 #' }
 #' @export
 ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
-  if( "auto" %in% height )
-    stop("'height:auto' is not supported", call. = FALSE)
-  if( "auto" %in% width )
-    stop("'width:auto' is not supported", call. = FALSE)
+  # if( "auto" %in% height )
+  #   stop("'height:auto' is not supported", call. = FALSE)
+  # if( "auto" %in% width )
+  #   stop("'width:auto' is not supported", call. = FALSE)
 
   shinyWidgetOutput(outputId, 'girafe', package = 'ggiraph', width = width, height = height)
 }
