@@ -29,7 +29,6 @@
 #' @param code Plotting code to execute
 #' @param ggobj ggplot objet to print. argument \code{code} will
 #' be ignored if this argument is supplied.
-#' @param width widget width ratio (0 < width <= 1). See below in section .
 #' @param width_svg,height_svg The width and height of the graphics region in inches.
 #' The default values are 6 and 5 inches. This will define the aspect ratio of the
 #' graphic as it will be used to define viewbox attribute of the SVG result.
@@ -38,7 +37,7 @@
 #' when parsing the svg result. This feature can be used to parse
 #' huge svg files by using \code{list(options = "HUGE")} but this
 #' is not recommanded.
-#' @param ... arguments passed on to \code{\link[rvg]{dsvg}}
+#' @param ... arguments passed on to \code{\link{dsvg}}
 #' @examples
 #' library(ggplot2)
 #'
@@ -89,10 +88,9 @@
 #' @seealso \code{\link{girafe_options}}
 #' @export
 girafe <- function(
-  code, ggobj = NULL,  width = 0.9, pointsize = 12,
+  code, ggobj = NULL,  pointsize = 12,
   width_svg = 6, height_svg = 5, xml_reader_options = list(), ...) {
 
-  stopifnot( is.numeric(width), width > 0, width <= 1 )
   canvas_id <- basename( tempfile(pattern = "svg_", fileext = format(Sys.time(), "%Y%m%d%H%M%S") ) )
   path = tempfile()
   dsvg(file = path, pointsize = pointsize, standalone = TRUE,
@@ -122,16 +120,18 @@ girafe <- function(
   zoom_set <- opts_zoom()
   selection_set <- opts_selection()
   toolbar_set <- opts_toolbar()
+  sizing_set <- opts_sizing()
 
   x = list( html = as.character(data), js = js,
-            uid = canvas_id, width = width,
+            uid = canvas_id,
             ratio = width_svg / height_svg,
             settings = list(
               tooltip = tooltip_set,
               hover = hover_set,
               zoom = zoom_set,
               capture = selection_set,
-              toolbar = toolbar_set
+              toolbar = toolbar_set,
+              sizing = sizing_set
               )
             )
 
@@ -152,10 +152,10 @@ girafe <- function(
 #' @param height widget height
 #' @export
 girafeOutput <- function(outputId, width = "100%", height = "500px"){
-  if( "auto" %in% height )
-    stop("'height:auto' is not supported", call. = FALSE)
-  if( "auto" %in% width )
-    stop("'width:auto' is not supported", call. = FALSE)
+  # if( "auto" %in% height )
+  #   stop("'height:auto' is not supported", call. = FALSE)
+  # if( "auto" %in% width )
+  #   stop("'width:auto' is not supported", call. = FALSE)
 
   shinyWidgetOutput(outputId, 'girafe', package = 'ggiraph', width = width, height = height)
 }
