@@ -31,11 +31,11 @@ interactive_polyline_grob <- function(x=unit(c(0, 1), "npc"),
 #' @description draw an interactive_polyline_grob
 #' @inheritParams grid::drawDetails
 drawDetails.interactive_polyline_grob <- function(x,recording) {
-	rvg_tracer_on()
+  dsvg_tracer_on()
 	argnames = setdiff( names(x), c("tooltip", "onclick", "data_id") )
 	do.call( grid.polyline, x[argnames] )
 
-	ids = rvg_tracer_off()
+	ids <- dsvg_tracer_off()
 	if( length( ids ) > 0 ) {
 
 	  if( is.null(x$id) && is.null(x$id.lengths) )
