@@ -31,11 +31,11 @@ interactive_text_grob <- function(label, x=unit(0.5, "npc"), y=unit(0.5, "npc"),
 #' @description draw an interactive_text_grob
 #' @inheritParams grid::drawDetails
 drawDetails.interactive_text_grob <- function(x,recording) {
-	rvg_tracer_on()
+  dsvg_tracer_on()
 	argnames = setdiff( names(x), c("tooltip", "onclick", "data_id") )
 	do.call( grid.text, x[argnames] )
 
-	ids = rvg_tracer_off()
+	ids <- dsvg_tracer_off()
 	if( length( ids ) > 0 ) {
 	  if( !is.null( x$tooltip ))
 	    set_attr( ids = as.integer( ids ), str = encode_cr(x$tooltip), attribute = "title" )
